@@ -1,7 +1,10 @@
 from json import loads
 import os
+import sys
 
-print(os.getcwd())
+print(os.path.dirname(os.path.realpath(__file__)))
+print(sys.path[0])
+print(os.path.dirname(os.path.realpath(sys.argv[0])))
 
 def nori(args):
     verb = None
@@ -85,7 +88,7 @@ def build(args):
     if args["Kasua"] == "NOR":
         if args["Nork"] != None or args["Nori"] != None:
             raise ValueError('Incorrect value for Nork and/or Nori: If Kasua = Nor, Nork and Nori must be = None. Read README.txt or the documentation at https://github.com/HCook86/Aditzak/blob/heroku/README.md for more information')
-        handler = open("./nor.json", "r")
+        handler = open("nor.json", "r")
         file = loads(handler.read())
         try:
             args["Aditza"] = file[args["Modua"]][args["Denbora"]][args["Nor"]]
@@ -334,7 +337,7 @@ def build(args):
 
     elif args["Kasua"] == "NOR-NORK":
         print("NOR-NORK")
-        handler = open("./nk3.json", "r")
+        handler = open("nk3.json", "r")
         file = loads(handler.read())
         try:
             if args["Nor"] == "hura":
